@@ -1,24 +1,21 @@
 #######################################################################
-# This file is part of PyBlosxom.
+# This file is part of Pyblosxom.
 #
-# Copyright (c) 2003, 2004, 2005, 2006 Wari Wahab
-# 
-# PyBlosxom is distributed under the MIT license.  See the file LICENSE
-# for distribution details.
+# Copyright (C) 2003-2011 by the Pyblosxom team.  See AUTHORS.
 #
-# $Id: fileentry.py 913 2006-08-08 20:29:42Z willhelm $
+# Pyblosxom is distributed under the MIT license.  See the file
+# LICENSE for distribution details.
 #######################################################################
-"""
-This module contains FileEntry class which is used to retrieve entries 
-from a file system.  Since pulling data from the file system and parsing 
-it is expensive (especially when you have 100s of entries) we delay
-fetching data until it's demanded.
 
-The FileEntry calls EntryBase methods addToCache and getFromCache
-to handle caching.
 """
+This module contains FileEntry class which is used to retrieve entries
+from a file system.  Since pulling data from the file system and
+parsing it is expensive (especially when you have 100s of entries) we
+delay fetching data until it's demanded.
 
-__revision__ = "$Revision: 913 $"
+The FileEntry calls EntryBase methods addToCache and getFromCache to
+handle caching.
+"""
 
 import time
 import os
@@ -33,21 +30,17 @@ class FileEntry(base.EntryBase):
     """
     def __init__(self, request, filename, root, datadir=""):
         """
-        @param request: the Request object
-        @type  request: Request
+        :param request: the Request object
 
-        @param filename: the complete filename for the file in question
-            including path
-        @type  filename: string
+        :param filename: the complete filename for the file in question
+                         including path
 
-        @param root: i have no clue what this is
-        @type  root: string
+        :param root: i have no clue what this is
 
-        @param datadir: the datadir
-        @type  datadir: string
+        :param datadir: the datadir
         """
         base.EntryBase.__init__(self, request)
-        self._config = request.getConfiguration()
+        self._config = request.get_configuration()
         self._filename = filename.replace(os.sep, '/')
         self._root = root.replace(os.sep, '/')
 
@@ -62,78 +55,57 @@ class FileEntry(base.EntryBase):
         self._populated_data = 0
 
     def __repr__(self):
-        """
-        Returns a representation of this instance with the filename
-        and root.
-        """
         return "<fileentry f'%s' r'%s'>" % (self._filename, self._root)
 
-    def setTimeLazy(self, timetuple):
-        """
-        Set the time without populating the entry.
-
-        @param timetuple: the mtime of the file (same as returned by 
-                          time.localtime(...))   
-        @type  timetuple: tuple of 9 ints     
-        """
-        self._timetuple = timetuple
-        self._mtime = time.mktime(timetuple)
-        self._fulltime = time.strftime("%Y%m%d%H%M%S", timetuple)
-
-    def getId(self):
+    def get_id(self):
         """
         Returns the id for this content item--in this case, it's the
         filename.
 
-        @returns: the id of the fileentry (the filename)
-        @rtype: string
+        :returns: the id of the fileentry (the filename)
         """
         return self._filename
 
-    def getData(self):
+    getId = tools.deprecated_function(get_id)
+
+    def get_data(self):
         """
         Returns the data for this file entry.  The data is the parsed
         (via the entryparser) content of the entry.  We do this on-demand
         by checking to see if we've gotten it and if we haven't then
         we get it at that point.
 
-        @returns: the content for this entry
-        @rtype: string
+        :returns: the content for this entry
         """
         if self._populated_data == 0:
-            self.__populatedata()
+            self._populatedata()
         return self._data
 
-    def getMetadata(self, key, default=None):
+    getData = tools.deprecated_function(get_data)
+
+    def get_metadata(self, key, default=None):
         """
-        This overrides the L{base.EntryBase} getMetadata method.
+        This overrides the ``base.EntryBase`` ``get_metadata`` method.
 
-        Note: We populate our metadata lazily--only when it's requested.
-        This delays parsing of the file as long as we can.
+        .. Note::
 
-        @param key: the key being sought
-        @type  key: varies
-
-        @param default: the default to return if the key does not
-            exist
-        @type  default: varies
-
-        @return: either the default (if the key did not exist) or the
-            value of the key in the metadata dict
-        @rtype: varies
+            We populate our metadata lazily--only when it's requested.
+            This delays parsing of the file as long as we can.
         """
         if self._populated_data == 0:
-            self.__populatedata()
+            self._populatedata()
 
         return self._metadata.get(key, default)
-        
-    def __populatedata(self):
+
+    getMetadata = tools.deprecated_function(get_metadata)
+
+    def _populatedata(self):
         """
-        Fills the metadata dict with metadata about the given file.  This
-        metadata consists of things we pick up from an os.stat call as
-        well as knowledge of the filename and the root directory.
-        We then parse the file and fill in the rest of the information
-        that we know.
+        Fills the metadata dict with metadata about the given file.
+        This metadata consists of things we pick up from an os.stat
+        call as well as knowledge of the filename and the root
+        directory.  We then parse the file and fill in the rest of the
+        information that we know.
         """
         file_basename = os.path.basename(self._filename)
 
@@ -165,12 +137,11 @@ class FileEntry(base.EntryBase):
         self['fn'] = filenamenoext
         self['filename'] = self._filename
 
-        # timetuple is set at __init__ time or by setTimeLazy
-        self.setTime(self._timetuple)
+        self.set_time(self._timetuple)
 
-        data = self._request.getData()
+        data = self._request.get_data()
 
-        entrydict = self.getFromCache(self._filename)
+        entrydict = self.get_from_cache(self._filename)
         if not entrydict:
             fileext = os.path.splitext(self._filename)
             if fileext:
@@ -178,9 +149,7 @@ class FileEntry(base.EntryBase):
 
             eparser = data['extensions'][fileext]
             entrydict = eparser(self._filename, self._request)
-            self.addToCache(self._filename, entrydict)
+            self.add_to_cache(self._filename, entrydict)
 
         self.update(entrydict)
         self._populated_data = 1
-
-# vim: tabstop=4 shiftwidth=4
