@@ -1,44 +1,46 @@
 #######################################################################
-# This file is part of PyBlosxom.
+# This file is part of Pyblosxom.
 #
-# Copyright (c) 2003, 2004, 2005, 2006 Wari Wahab
-# 
-# PyBlosxom is distributed under the MIT license.  See the file LICENSE
-# for distribution details.
+# Copyright (C) 2003-2011 by the Pyblosxom team.  See AUTHORS.
 #
-# $Id: plugin_utils.py 1012 2007-05-19 17:57:07Z willhelm $
+# Pyblosxom is distributed under the MIT license.  See the file
+# LICENSE for distribution details.
 #######################################################################
+
 """
 Holds a series of utility functions for cataloguing, retrieving, and
 manipulating callback functions and chains.  Refer to the documentation
 for which callbacks are available and their behavior.
 """
 
-__revision__ = "$Revision: 1012 $"
-
 import os
 import glob
 import sys
 import os.path
+import traceback
+
 
 # this holds the list of plugins that have been loaded.  if you're running
-# PyBlosxom as a long-running process, this only gets cleared when the
+# Pyblosxom as a long-running process, this only gets cleared when the
 # process is restarted.
 plugins = []
 
 # this holds a list of callbacks (any function that begins with cp_) and the
 # list of function instances that support that callback.
-# if you're running PyBlosxom as a long-running process, this only
+# if you're running Pyblosxom as a long-running process, this only
 # gets cleared when the process is restarted.
 callbacks = {}
 
+# this holds a list of (plugin name, exception) tuples for plugins that
+# didn't import.
+bad_plugins = []
+
 def catalogue_plugin(plugin_module):
     """
     Goes through the plugin's contents and catalogues all the functions
     that start with cb_.  Functions that start with cb_ are callbacks.
 
-    @param plugin_module: the module to catalogue
-    @type  plugin_module: module
+    :param plugin_module: the module to catalogue
     """
     listing = dir(plugin_module)
 
@@ -49,7 +51,7 @@ def catalogue_plugin(plugin_module):
         memadj = mem[3:]
         if callable(func):
             callbacks.setdefault(memadj, []).append(func)
-            
+
 def get_callback_chain(chain):
     """
     Returns a list of functions registered with the callback.
@@ -71,18 +73,18 @@ def initialize_plugins(plugin_dirs, plugin_list):
     load_plugins key does not exist, then we load all the plugins in the
     plugins directory using an alphanumeric sorting order.
 
-    NOTE: If PyBlosxom is part of a long-running process, you must
-    restart PyBlosxom in order to pick up any changes to your plugins.
+    .. Note::
 
-    @param plugin_dirs: the list of directories to add to the sys.path
-        because that's where our plugins are located.
-    @type  plugin_dirs: list of strings
+       If Pyblosxom is part of a long-running process, you must
+       restart Pyblosxom in order to pick up any changes to your plugins.
 
-    @param plugin_list: the list of plugins to load, or if None, we'll
-        load all the plugins we find in those dirs.
-    @type  plugin_list: list of strings or None
+    :param plugin_dirs: the list of directories to add to the sys.path
+                        because that's where our plugins are located.
+
+    :param plugin_list: the list of plugins to load, or if None, we'll
+                        load all the plugins we find in those dirs.
     """
-    if plugins:
+    if plugins or bad_plugins:
         return
 
     # we clear out the callbacks dict so we can rebuild them
@@ -99,7 +101,15 @@ def initialize_plugins(plugin_dirs, plugin_list):
     plugin_list = get_plugin_list(plugin_list, plugin_dirs)
 
     for mem in plugin_list:
-        _module = __import__(mem)
+        try:
+            _module = __import__(mem)
+        except (SystemExit, KeyboardInterrupt):
+            raise
+        except:
+            # this needs to be a catch-all
+            bad_plugins.append((mem, "".join(traceback.format_exc())))
+            continue
+
         for comp in mem.split(".")[1:]:
             _module = getattr(_module, comp)
         catalogue_plugin(_module)
@@ -110,11 +120,9 @@ def get_plugin_by_name(name):
     This retrieves a plugin instance (it's a Python module instance)
     by name.
 
-    @param name: the name of the plugin to retrieve (ex: "xmlrpc")
-    @type  name: string
+    :param name: the name of the plugin to retrieve (ex: "xmlrpc")
 
-    @returns: the Python module instance for the plugin or None
-    @rtype: Python module
+    :returns: the Python module instance for the plugin or None
     """
     if plugins:
         for mem in plugins:
@@ -128,29 +136,24 @@ def get_module_name(filename):
 
     Example: passing in "/blah/blah/blah/module.ext" returns "module"
 
-    @param filename: the filename in question (with a full path)
-    @type  filename: string
+    :param filename: the filename in question (with a full path)
 
-    @returns: the filename without path or extension
-    @rtype:   string
+    :returns: the filename without path or extension
     """
     return os.path.splitext(os.path.split(filename)[1])[0]
 
-def get_plugin_list(plugin_list, plugin_dirs):    
+def get_plugin_list(plugin_list, plugin_dirs):
     """
     This handles the situation where the user has provided a series of
     plugin dirs, but has not specified which plugins they want to load
     from those dirs.  In this case, we load all possible plugins except
-    the ones whose names being with _ .  
+    the ones whose names being with _ .
 
-    @param plugin_list: List of plugins to load
-    @type plugin_list: list or None
+    :param plugin_list: List of plugins to load
 
-    @param plugin_dirs: A list of directories where plugins can be loaded from
-    @type plugin_dirs: list
+    :param plugin_dirs: A list of directories where plugins can be loaded from
 
-    @return: list of python module names of the plugins to load
-    @rtype: list of strings
+    :return: list of python module names of the plugins to load
     """
     if plugin_list == None:
         plugin_list = []
@@ -167,5 +170,3 @@ def get_plugin_list(plugin_list, plugin_dirs):
         plugin_list.sort()
 
     return plugin_list
-
-# vim: shiftwidth=4 tabstop=4 expandtab
