@@ -166,7 +166,7 @@ Related files
 .. only:: text
 
    You can find the comment-story file in the docs at
-   http://pyblosxom.bluesock.org/ or in the tarball under
+   http://pyblosxom.github.com/ or in the tarball under
    docs/_static/plugins/comments/.
 
 
@@ -208,7 +208,7 @@ Variables available:
 .. only:: text
 
    You can find the comment-story file in the docs at
-   http://pyblosxom.bluesock.org/ or in the tarball under
+   http://pyblosxom.github.com/ or in the tarball under
    docs/_static/plugins/comments/.
 
 
@@ -240,7 +240,7 @@ Variables available::
 .. only:: text
 
    You can find the comment-story file in the docs at
-   http://pyblosxom.bluesock.org/ or in the tarball under
+   http://pyblosxom.github.com/ or in the tarball under
    docs/_static/plugins/comments/.
 
 
@@ -259,7 +259,7 @@ comment form used to enter new comments.
 .. only:: text
 
    You can find the comment-story file in the docs at
-   http://pyblosxom.bluesock.org/ or in the tarball under
+   http://pyblosxom.github.com/ or in the tarball under
    docs/_static/plugins/comments/.
 
 
@@ -339,7 +339,7 @@ If you would like comment previews, you need to do 2 things.
 .. only:: text
 
    You can find the comment-story file in the docs at
-   http://pyblosxom.bluesock.org/ or in the tarball under
+   http://pyblosxom.github.com/ or in the tarball under
    docs/_static/plugins/comments/.
 
 
@@ -457,7 +457,7 @@ entry.
 __author__ = "Ted Leung, et al"
 __email__ = "pyblosxom-devel at sourceforge dot net"
 __version__ = "2011-12-17"
-__url__ = "http://pyblosxom.bluesock.org/"
+__url__ = "http://pyblosxom.github.com/"
 __description__ = "Adds comments to a blog entry."
 __category__ = "comments"
 __license__ = "MIT"
@@ -1134,12 +1134,18 @@ class AjaxRenderer(blosxom.Renderer):
         out = request.get_configuration().get('stdoutput', sys.stdout)
         blosxom.Renderer.__init__(self, request, out)
         self._ajax_type = request.get_http()['form']['ajax'].value
+        self._config = request.get_configuration()
         self._data = data
 
     def _should_output(self, entry, template_name):
         """ Return whether we should output this template, depending on the
         type of ajax request we're responding to.
         """
+
+        if (self._ajax_type == 'post' and template_name == 'story'):
+            entry['comments'] = read_comments(entry, self._config)
+            return False
+
         if self._ajax_type == 'preview' and template_name == 'comment-preview':
             return True
         elif (self._ajax_type == 'post' and template_name == 'comment'
@@ -1151,7 +1157,8 @@ class AjaxRenderer(blosxom.Renderer):
     def render_template(self, entry, template_name, override=0):
         if self._should_output(entry, template_name):
             return blosxom.Renderer.render_template(
-                entry, template_name, override)
+                self, entry, template_name, override)
+        else: return ""
 
     def _output_flavour(self, entry, template_name):
         if self._should_output(entry, template_name):
@@ -1334,7 +1341,7 @@ def cb_story_end(args):
          and not entry.has_key('nocomments')
          and data['display_comment_default'])):
         output = []
-        if entry['comments']:
+        if entry.get('comments', []):
             comment_entry_base = dict(entry)
             del comment_entry_base['comments']
             for comment in entry['comments']:
